add_biplot_arrows: Adds a biplot arrow layer to an existing plot
Description
Adds a biplot arrow layer to an existing plot
Usage
add_biplot_arrows(object, plt, vars, arrow.col = "navy")
Arguments
- object
an ordination object.
- plt
a ggplot object.
- vars
character; length 2 vector of dimension names.
- arrow.col
colour specification for biplot arrows and their labels.