powered by
"anosim"
Produces a multi-layer ggplot object representing the output of objects produced by vegan::anosim().
vegan::anosim()
# S3 method for anosim autoplot( object, notch = TRUE, varwidth = TRUE, xlab = NULL, ylab = NULL, title = "Analysis of similarities", subtitle = NULL, caption = bquote(R == .(r) * "," ~ P == .(p)), ... )
A ggplot object.
an object of class "anosim", the result of a call to vegan::anosim().
logical; make notched (default) or standard box plot?
logical; make box width proportional to the square-root of the number of observations in the group (default)?
character; label for the x-axis.
character; label for the y-axis.
character; title for the plot.
character; subtitle for the plot.
character; caption for the plot.
additional arguments passed to other methods.
Didzis Elferts. Modifications by Gavin L. Simpson.
library("vegan") data(dune) data(dune.env) dune.dist <- vegdist(dune) dune.ano <- with(dune.env, anosim(dune.dist, Management)) autoplot(dune.ano, notch = FALSE)
Run the code above in your browser using DataLab