powered by
"isomap"
Produces a multi-layer ggplot object representing the output of objects produced by vegan::isomap().
vegan::isomap()
# S3 method for isomap autoplot( object, axes = c(1, 2), geom = c("point", "text"), network = TRUE, line.col = "grey85", linewidth = 0.7, xlab = NULL, ylab = NULL, title = "Isometric feature mapping", subtitle = NULL, caption = NULL, ... )
A ggplot object.
an object of class "isomap", the result of a call to vegan::isomap().
numeric; which axes to plot, given as a vector of length 2.
character; which geom to use for the MDS scores layer.
logical; should the edges of the ISOMAP network be drawn?
colour with which to draw the network edges.
numeric; linewidth aesthetic for the log-series curve.
character; label for the x-axis.
character; label for the y-axis.
character; subtitle for the plot.
character; caption for the plot.
additional arguments passed to other methods.
Gavin L. Simpson
library("vegan") data(BCI) dis <- vegdist(BCI) ord <- isomap(dis, k = 3) autoplot(ord) autoplot(ord, geom = "text")
Run the code above in your browser using DataLab