ggplot-based plot for objects of class "prc"
autoplot.prc.RdProduces a multi-layer ggplot object representing the output of
objects produced by vegan::prc().
Usage
# S3 method for class 'prc'
autoplot(
object,
select,
xlab,
ylab,
title = NULL,
subtitle = NULL,
caption = NULL,
legend.position = "top",
...
)Arguments
- object
an object inheriting from class
"prc", the result of a call tovegan::prc().- select
a logical vector where
TRUEselects andFALSEdeselects species. Alternatively a numeric vector that contains the indices selecting species. Note that these are with respect to the original species matrix, not the fortified object.- xlab
character; label for the x-axis
- ylab
character; label for the y-axis
- title
character; subtitle for the plot
- subtitle
character; subtitle for the plot
- caption
character; caption for the plot
- legend.position
character; position for the legend grob. See argument
legend.positionin functionggplot2::theme().- ...
Additional arguments passed to
\link{fortify.prc}.