Extract the names of the dimensions to plot as a character vector
Source:R/utils.R
get_dimension_names.RdFind the character vector of names for the two dimensions of data to be plotted.
R/utils.R
get_dimension_names.RdFind the character vector of names for the two dimensions of data to be plotted.