powered by
"dbrda"
Produces a multi-layer ggplot object representing the output of objects produced by vegan::dbrda().
vegan::dbrda()
# S3 method for dbrda autoplot( object, axes = c(1, 2), geom = c("point", "text"), layers = c("sites", "biplot", "centroids"), legend.position = "none", title = NULL, subtitle = NULL, caption = NULL, ylab = NULL, xlab = NULL, const = NULL, arrow.col = "navy", ... )
Returns a ggplot object.
an object of class "dbrda", the result of a call to vegan::dbrda()
numeric; which axes to plot, given as a vector of length 2.
character; which geom to use for the site (sample) scores. One of "point", or "text".
"point"
"text"
character; which scores to plot as layers
character or two-element numeric vector; where to position the legend. See ggplot2::theme() for details. Use "none" to not draw the legend.
ggplot2::theme()
"none"
character; subtitle for the plot.
character; caption for the plot.
character; label for the y-axis.
character; label for the x-axis.
General scaling constant to dbrda scores. See vegan::scores.rda() for details.
dbrda
vegan::scores.rda()
colour specification for biplot arrows and their labels.
Additional arguments passed to the fortify() method.
fortify()
Gavin L. Simpson
TODO
library("vegan") data(dune, dune.env) dune_dbrda <- dbrda( dune ~ A1 + Moisture + Use + Management, data = dune.env ) autoplot(dune_dbrda)
Run the code above in your browser using DataLab