powered by
"poolaccum"
Produces a multi-layer ggplot object representing the output of objects produced by vegan::poolaccum().
vegan::poolaccum()
# S3 method for poolaccum autoplot( object, facet = TRUE, ribbon = facet, ncol = NULL, ribbon.alpha = 0.3, xlab = "Size", ylab = "Richness", title = "Accumulated species richness", subtitle = NULL, caption = NULL, ... )
A ggplot object.
an object of class "poolaccum", the result of a call to vegan::poolaccum().
logical; should extrapolated richness estimators be shown in separate facets?
logical; show the quantile-based uncertainty interval? Uses ggplot2::geom_ribbon() for plot.
ggplot2::geom_ribbon()
numeric; if faceting the plot, how many columns to use. Default arguments will result in three columns.
numeric; alpha transparency used for the uncertainty interval. Passed to the alpha aesthetic of ggplot2::geom_ribbon().
alpha
character; label for the x axis.
character; label for the y axis.
character; title for the plot.
character; subtitle for the plot.
character; caption for the plot.
additional arguments passed to fortify.poolaccum().
fortify.poolaccum()
Didzis Elferts & Gavin L. Simpson
library("vegan") data(BCI) pool <- poolaccum(BCI) autoplot(pool) ## Turn off facetting; turns off ribbon too autoplot(pool, facet = FALSE)
Run the code above in your browser using DataLab