fortify.decorana: Fortify a '"decorana"' object.

fortify.decoranaR Documentation

Fortify a "decorana" object.

Description

Fortifies an object of class "decorana" to produce a data frame of the selected axis scores in long format, suitable for plotting with ggplot2::ggplot().

Usage

## S3 method for class 'decorana'
fortify(model, data, axes = 1:4, layers = c("sites", "species"), ...)

## S3 method for class 'decorana'
tidy(x, data, axes = 1:4, layers = c("sites", "species"), ...)

Arguments

model, x

an object of class "decorana", the result of a call to vegan::decorana().

data

currently ignored.

axes

numeric; which axis scores are required?

layers

character; the scores to extract in the fortified object.

...

additional arguments passed to vegan::scores.decorana().

Details

TODO

Value

A data frame in long format containing the ordination scores. The first two components are the axis scores.

Author(s)

Gavin L. Simpson

Examples


library("vegan")

data(dune)

sol <- decorana(dune)
head(fortify(sol))
head(fortify(sol, layers = "species"))

ggvegan documentation built on Feb. 28, 2026, 1:07 a.m.