| fortify.decorana | R Documentation |
"decorana" object.Fortifies an object of class "decorana" to produce a data
frame of the selected axis scores in long format, suitable for plotting
with ggplot2::ggplot().
## S3 method for class 'decorana'
fortify(model, data, axes = 1:4, layers = c("sites", "species"), ...)
## S3 method for class 'decorana'
tidy(x, data, axes = 1:4, layers = c("sites", "species"), ...)
model, x |
an object of class |
data |
currently ignored. |
axes |
numeric; which axis scores are required? |
layers |
character; the scores to extract in the fortified object. |
... |
additional arguments passed to |
TODO
A data frame in long format containing the ordination scores. The first two components are the axis scores.
Gavin L. Simpson
library("vegan")
data(dune)
sol <- decorana(dune)
head(fortify(sol))
head(fortify(sol, layers = "species"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.