Learn R Programming

ggvegan (version 0.2.1)

fortify.decorana: Fortify a "decorana" object.

Description

Fortifies an object of class "decorana" to produce a data frame of the selected axis scores in long format, suitable for plotting with ggplot2::ggplot().

Usage

# S3 method for decorana
fortify(model, data, axes = 1:4, layers = c("sites", "species"), ...)

# S3 method for decorana tidy(x, data, axes = 1:4, layers = c("sites", "species"), ...)

Value

A data frame in long format containing the ordination scores. The first two components are the axis scores.

Arguments

model, x

an object of class "decorana", the result of a call to vegan::decorana().

data

currently ignored.

axes

numeric; which axis scores are required?

layers

character; the scores to extract in the fortified object.

...

additional arguments passed to vegan::scores.decorana().

Author

Gavin L. Simpson

Details

TODO

Examples

Run this code

library("vegan")

data(dune)

sol <- decorana(dune)
head(fortify(sol))
head(fortify(sol, layers = "species"))

Run the code above in your browser using DataLab