powered by
"decorana"
Fortifies an object of class "decorana" to produce a data frame of the selected axis scores in long format, suitable for plotting with ggplot2::ggplot().
ggplot2::ggplot()
# S3 method for decorana fortify(model, data, axes = 1:4, layers = c("sites", "species"), ...)# S3 method for decorana tidy(x, data, axes = 1:4, layers = c("sites", "species"), ...)
# S3 method for decorana tidy(x, data, axes = 1:4, layers = c("sites", "species"), ...)
A data frame in long format containing the ordination scores. The first two components are the axis scores.
an object of class "decorana", the result of a call to vegan::decorana().
vegan::decorana()
currently ignored.
numeric; which axis scores are required?
character; the scores to extract in the fortified object.
additional arguments passed to vegan::scores.decorana().
vegan::scores.decorana()
Gavin L. Simpson
TODO
library("vegan") data(dune) sol <- decorana(dune) head(fortify(sol)) head(fortify(sol, layers = "species"))
Run the code above in your browser using DataLab