fortify.envfit: Fortify method for 'envfit' objects

fortify.envfitR Documentation

Fortify method for envfit objects

Description

Produces a tidy data frame from the results of an vegan::envfit() object.

Usage

## S3 method for class 'envfit'
fortify(model, data, ...)

## S3 method for class 'envfit'
tidy(x, data, ...)

Arguments

model, x

an object of class envfit, the result of a call to vegan::envfit().

data

additional data to augment the envfit results. Currently ignored.

...

arguments passed to vegan::scores.envfit().

Value

A data frame with columns label, type, containing the label for, and whether each row refers to, the fitted vector or factor. Remaining variables are coordinates on the respective ordination axes returned by vegan::scores.envfit().

Author(s)

Gavin L. Simpson

Examples


library("vegan")

data(varespec, varechem)
ord <- metaMDS(varespec)
fit <- envfit(ord, varechem, perm = 199)

fortify(fit)

data(dune, dune.env)
ord <- ca(dune)
fit <- envfit(ord ~ Moisture + A1, dune.env, perm = 199)

fortify(fit)

ggvegan documentation built on Feb. 28, 2026, 1:07 a.m.