| fortify.envfit | R Documentation |
envfit objectsProduces a tidy data frame from the results of an
vegan::envfit() object.
## S3 method for class 'envfit'
fortify(model, data, ...)
## S3 method for class 'envfit'
tidy(x, data, ...)
model, x |
an object of class |
data |
additional data to augment the |
... |
arguments passed to |
A data frame with columns label, type, containing the label for,
and whether each row refers to, the fitted vector or factor. Remaining
variables are coordinates on the respective ordination axes returned by
vegan::scores.envfit().
Gavin L. Simpson
library("vegan")
data(varespec, varechem)
ord <- metaMDS(varespec)
fit <- envfit(ord, varechem, perm = 199)
fortify(fit)
data(dune, dune.env)
ord <- ca(dune)
fit <- envfit(ord ~ Moisture + A1, dune.env, perm = 199)
fortify(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.