Learn R Programming

ggvegan (version 0.2.1)

fortify.envfit: Fortify method for envfit objects

Description

Produces a tidy data frame from the results of an vegan::envfit() object.

Usage

# S3 method for envfit
fortify(model, data, ...)

# S3 method for envfit tidy(x, data, ...)

Value

A data frame with columns label, type, containing the label for, and whether each row refers to, the fitted vector or factor. Remaining variables are coordinates on the respective ordination axes returned by vegan::scores.envfit().

Arguments

model, x

an object of class envfit, the result of a call to vegan::envfit().

data

additional data to augment the envfit results. Currently ignored.

...

arguments passed to vegan::scores.envfit().

Author

Gavin L. Simpson

Examples

Run this code

library("vegan")

data(varespec, varechem)
ord <- metaMDS(varespec)
fit <- envfit(ord, varechem, perm = 199)

fortify(fit)

data(dune, dune.env)
ord <- ca(dune)
fit <- envfit(ord ~ Moisture + A1, dune.env, perm = 199)

fortify(fit)

Run the code above in your browser using DataLab