fortify.fisherfit: Tidied species rank abundance data and estimated Fisher's...

fortify.fisherfitR Documentation

Tidied species rank abundance data and estimated Fisher's log-series

Description

Prepares a data frame of results from a vegan::fisherfit()) object suitable for plotting with ggplot2::ggplot()).

Usage

## S3 method for class 'fisherfit'
fortify(model, data, ...)

## S3 method for class 'fisherfit'
tidy(x, data, ...)

Arguments

model, x

an object of class vegan::fisherfit()).

data

original data set. Currently ignored.

...

other arguments pass to methods. Currently ignored.

Value

A data frame with columns 'Rank' and 'Abundance'. Additionally, Fisher's \alpha and the nuisance parameter are returned as attributes 'alpha' and 'k' respectively.

Author(s)

Gavin L. Simpson

Examples


library("vegan")

data(BCI)
mod <- fisherfit(BCI[5,])
head(fortify(mod))

ggvegan documentation built on Feb. 28, 2026, 1:07 a.m.