| fortify.metaMDS | R Documentation |
"mataMDS" object.Fortifies an object of class "metaMDS" to produce a
data frame of the selected axis scores in long format, suitable for
plotting with ggplot2::ggplot().
## S3 method for class 'metaMDS'
fortify(model, data, axes = 1:2, layers = c("sites", "species"), ...)
## S3 method for class 'metaMDS'
tidy(x, data, layers = c("sites", "species"), ...)
model, x |
an object of class |
data |
currently ignored. |
axes |
numeric; which axes to extract scores for. |
layers |
character; the scores to extract in the fortified object.
Passed to |
... |
additional arguments passed to
|
TODO
A data frame in long format containing the ordination scores. The first two components are the axis scores.
Gavin L. Simpson
library("vegan")
data(dune)
ord <- metaMDS(dune)
head(fortify(ord))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.