powered by
"mataMDS"
Fortifies an object of class "metaMDS" to produce a data frame of the selected axis scores in long format, suitable for plotting with ggplot2::ggplot().
"metaMDS"
ggplot2::ggplot()
# S3 method for metaMDS fortify(model, data, axes = 1:2, layers = c("sites", "species"), ...)# S3 method for metaMDS tidy(x, data, layers = c("sites", "species"), ...)
# S3 method for metaMDS tidy(x, data, layers = c("sites", "species"), ...)
A data frame in long format containing the ordination scores. The first two components are the axis scores.
an object of class "metaMDS", the result of a call to vegan::metaMDS().
vegan::metaMDS()
currently ignored.
numeric; which axes to extract scores for.
character; the scores to extract in the fortified object. Passed to display in the respective vegan::scores() method.
display
vegan::scores()
additional arguments passed to vegan::scores.metaMDS(). Note you can't use display.
vegan::scores.metaMDS()
Gavin L. Simpson
TODO
library("vegan") data(dune) ord <- metaMDS(dune) head(fortify(ord))
Run the code above in your browser using DataLab