Learn R Programming

ggvegan (version 0.2.1)

fortify.permustats: Fortify permutation statistics

Description

Fortify permutation statistics

Usage

# S3 method for permustats
fortify(model, data, scale = FALSE, ...)

# S3 method for permustats tidy(x, data, scale = FALSE, ...)

Value

A tibble with columns permutations, and terms containing the values of tests statistics under the null hypothesis, and a factor labelling the permutation, respectively.

Arguments

model, x

an object of created by vegan::permustats().

data

original data set. Currently ignored.

scale

logical; return standardized effect sizes (SES)?

...

Other parameters passed to functions (ignored).

Examples

Run this code
library("vegan")
data(dune, dune.env, package = "vegan")
mod <- adonis2(dune ~ Management + A1, data = dune.env)
## use permustats
perm <- permustats(mod)

Run the code above in your browser using DataLab