powered by
Fortify permutation statistics
# S3 method for permustats fortify(model, data, scale = FALSE, ...)# S3 method for permustats tidy(x, data, scale = FALSE, ...)
# S3 method for permustats tidy(x, data, scale = FALSE, ...)
A tibble with columns permutations, and terms containing the values of tests statistics under the null hypothesis, and a factor labelling the permutation, respectively.
permutations
terms
an object of created by vegan::permustats().
vegan::permustats()
original data set. Currently ignored.
logical; return standardized effect sizes (SES)?
Other parameters passed to functions (ignored).
library("vegan") data(dune, dune.env, package = "vegan") mod <- adonis2(dune ~ Management + A1, data = dune.env) ## use permustats perm <- permustats(mod)
Run the code above in your browser using DataLab