| fortify.rda | R Documentation |
"rda" object.Fortifies an object of class "rda" to produce a
data frame of the selected axis scores in long format, suitable for
plotting with ggplot2::ggplot().
## S3 method for class 'rda'
fortify(
model,
data = NULL,
axes = 1:6,
layers = c("sp", "wa", "lc", "bp", "cn"),
const = NULL,
...
)
## S3 method for class 'rda'
tidy(
x,
data = NULL,
axes = 1:6,
layers = c("sp", "wa", "lc", "bp", "reg", "cn"),
const = NULL,
...
)
model, x |
an object of class |
data |
currently ignored. |
axes |
numeric; which axes to extract scores for. |
layers |
character; the scores to extract in the fortified object.
Passed to |
const |
NULL; General scaling constant to RDA scores. See
|
... |
additional arguments passed to |
TODO
A data frame (tibble) in long format containing the ordination
scores. The first two components are score (the type of score in each
row) and label (the text label to use on plots for this row). The
remaining columns are the extracted ordination axis scores.
Gavin L. Simpson
library("vegan")
data(dune)
data(dune.env)
sol <- rda(dune ~ A1 + Management, data = dune.env)
head(fortify(sol))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.