fortify.vegan_pco: Fortify a '"vegan_pco"' object.

fortify.vegan_pcoR Documentation

Fortify a "vegan_pco" object.

Description

Fortifies an object of class "vegan_pco" to produce a data frame of the selected axis scores in long format, suitable for plotting with ggplot2::ggplot().

Usage

## S3 method for class 'vegan_pco'
fortify(model, data = NULL, axes = 1:6, ...)

## S3 method for class 'vegan_pco'
tidy(x, data = NULL, axes = 1:6, const = NULL, ...)

Arguments

model, x

an object of class "vegan_pco", the result of a call to vegan::pco().

data

currently ignored.

axes

numeric; which axes to extract scores for.

...

additional arguments passed to vegan::scores.rda().

const

NULL; General scaling constant to RDA scores. See vegan::scores.rda() for the details.

Details

TODO

Value

A data frame (tibble) in long format containing the ordination scores. The first two components are score (the type of score in each row) and label (the text label to use on plots for this row). The remaining columns are the extracted ordination axis scores.

Author(s)

Gavin L. Simpson

Examples


library("vegan")

data(dune)

sol <- pco(dune)
head(fortify(sol))

ggvegan documentation built on Feb. 28, 2026, 1:07 a.m.