Function adds a text layer to an ordiggplot() graph using
ggplot2::geom_text().
Arguments
- score
Ordination score to be added to the plot.
- data
Alternative data to the function that will be used instead of
score. This can be avegan::envfit()result object which is used to plot centroids of factor levels.- ...
other arguments passed to
ggplot2::geom_text()