Add a text layer to an ordiggplot
Arguments
- score
Ordination score to be added to the plot.
- data
Alternative data to the function that will be used instead of
score.- ...
other arguments passed to
ggplot2::geom_text()
Add a text layer to an ordiggplot
Ordination score to be added to the plot.
Alternative data to the function that will be used
instead of score.
other arguments passed to ggplot2::geom_text()