Extract the names of the dimensions to plot as a character vector
get_dimension_names.RdFind the character vector of names for the two dimensions of data to be plotted.
get_dimension_names.RdFind the character vector of names for the two dimensions of data to be plotted.