get_dimension_names: Extract the names of the dimensions to plot as a character...

get_dimension_namesR Documentation

Extract the names of the dimensions to plot as a character vector

Description

Find the character vector of names for the two dimensions of data to be plotted.

Usage

get_dimension_names(object)

Arguments

object

a fortified ordination object.

Value

A length 2 character vector of dimension names.

Author(s)

Gavin L. Simpson


ggvegan documentation built on Feb. 28, 2026, 1:07 a.m.