Learn R Programming

ggvegan (version 0.2.1)

get_dimension_names: Extract the names of the dimensions to plot as a character vector

Description

Find the character vector of names for the two dimensions of data to be plotted.

Usage

get_dimension_names(object)

Value

A length 2 character vector of dimension names.

Arguments

object

a fortified ordination object.

Author

Gavin L. Simpson