| label_fun | R Documentation |
Adds labels to a plot using one of ggplot2::geom_label(),
ggplot2::geom_text(), ggrepel::geom_label_repel() or
ggrepel::geom_text_repel().
label_fun(data, geom = c("label", "text", "label_repel", "text_repel"), vars)
data |
data frame; data set to use for the label layer. Must contain a variable label containing the strings to use as labels. |
geom |
character; which geom to use for labelling. |
vars |
character; vector of names of variables to pass to the |
Gavin L. Simpson
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.