Adds labels to a plot using one of geom_label, geom_text, geom_label_repel or geom_text_repel.
label_fun(data, geom = c("label", "text", "label_repel", "text_repel"),
vars)data frame; data set to use for the label layer. Must contain a variable Label containing the strings to use as labels.
character; which geom to use for labelling.
character; vector of names of variables to ass to the x and y aesthetics of the chosen geom.