Adds labels to a plot using one of ggplot2::geom_label(),
ggplot2::geom_text(), ggrepel::geom_label_repel() or
ggrepel::geom_text_repel().
label_fun(data, geom = c("label", "text", "label_repel", "text_repel"), vars)data frame; data set to use for the label layer. Must contain a variable label containing the strings to use as labels.
character; which geom to use for labelling.
character; vector of names of variables to pass to the x and
y aesthetics of the chosen geom.
Gavin L. Simpson